pub trait AsyncBufRead: for<'a> AsyncBufReadWith<'a> { }Expand description
Read bytes from a source that has an internal buffer asynchronously.
This is an asynchronous version of std::io::BufRead.
You should not implement this trait manually, instead implement AsyncBufReadWith.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".